<?php
namespace WPFunnels\FunnelType;

use WPFunnels\Wpfnl_functions;
use WPFunnels\FunnelType\Wpfnl_Public_Funnel_Type;
use WPFunnels\lms\helper\Wpfnl_lms_learndash_functions;
use WPFunnels\Meta\Wpfnl_Default_Meta;

class Wpfnl_Public_Wc extends Wpfnl_Public_Funnel_Type
{

    /**
     * When order bump accept/reject for woocommerce
     * 
     * @param
     * @return Array
     * 
     */
    public function wpfnl_order_bump_trigger( $step_id, $product_id, $quantity, $key, $user_id, $funnel_id , $checker ){
     
        //=== Custom price configured when you add sale price or apply coupon or add discount value ===//
        $ob_settings 			= get_post_meta($step_id, 'order-bump-settings', true);
        $replaceable_ob 		= $this->get_replaceable_ob_products( $ob_settings );
        $order_bump_settings 	= $ob_settings[$key];
        $_product 				= wc_get_product($product_id);
        $discount_type			= $order_bump_settings['discountOption'];

        $discount_apply_to  	= $_product->is_on_sale() ? 'sale' :  'regular' ;
        $product_price 			= $this->get_product_price( $_product, $discount_apply_to );

        
        
        if( 'discount-percentage' === $discount_type || 'discount-price' === $discount_type ) {
            $discount_apply_to 	= isset($order_bump_settings['discountapply']) ? $order_bump_settings['discountapply'] : 'regular';
            $discount_value 	= isset($order_bump_settings['discountValue']) ? $order_bump_settings['discountValue'] : 0;
            $product_price		= $this->get_product_price( $_product, $discount_apply_to );
            $product_price 		= $this->calculate_custom_price( $discount_type, $discount_value, $product_price );
        }

        $ob_cart_item_data = [
            'custom_price' 		=> preg_replace('/[^\d.]/', '', $product_price ),
            'wpfnl_order_bump' 	=> true,
        ];
        $data = array();
        $should_replace_first_product = isset($order_bump_settings['isReplace']) ? $order_bump_settings['isReplace'] : 'no';
        add_filter( 'woocommerce_checkout_cart_item_quantity', array($this, 'wpfnl_checkout_cart_item_quantity'), 10, 3 );
        if ($checker == "true") {
            $data = $this->wpfnl_order_bump_accept( $step_id, $product_id, $quantity, $key, $user_id, $funnel_id, $replaceable_ob, $ob_cart_item_data, $should_replace_first_product );
        }else{
            $data = $this->wpfnl_order_bump_reject( $step_id, $product_id, $quantity, $key, $user_id, $funnel_id, $replaceable_ob, $ob_cart_item_data, $should_replace_first_product );
        }
        return $data;
    }


    /**
     * When order bump accept for woocommerce
     * 
     * @param
     * @return Array
     */
    private function wpfnl_order_bump_accept( $step_id, $product_id, $quantity, $key, $user_id, $funnel_id, $replaceable_ob, $ob_cart_item_data, $should_replace_first_product ){
    
        if( Wpfnl_functions::is_wc_active() ){

            WC()->session->set('order_bump_accepted', 'yes');
            // if order bump is checked we will empty the cart in the first place. The we have to check if isReplace is yes or no.
            // if replace first product is enabled, then we will only add the order bump product
            // else we will add all the checkout product along with the order bump product
            if ( $should_replace_first_product == 'yes' ) {
                $checkout_products = get_post_meta( $step_id, '_wpfnl_checkout_products', true);
                $i = 0;
                foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                    $key = array_search( $cart_item['variation_id'] ? $cart_item['variation_id'] : $cart_item['product_id'], array_column($checkout_products, 'id'));
                    if( $key !== false ){
                        if( $cart_item['quantity'] == $checkout_products[$key]['quantity'] ){
                            if( $i === 0 ){
                                WC()->cart->remove_cart_item($cart_item_key);
                            }
                            $i++;
                            
                        }
                    }

                    $index = array_search( $cart_item['variation_id'] ? $cart_item['variation_id'] : $cart_item['product_id'], array_column($replaceable_ob, 'id'));
                    if( $index !== false ){
                        if( $cart_item['quantity'] == $replaceable_ob[$key]['quantity'] ){
                            if( $i === 0 ){
                                WC()->cart->remove_cart_item($cart_item_key);
                            }
                            $i++;
                        }
                    }
                }
                WC()->cart->add_to_cart($product_id, $quantity, 0, [], $ob_cart_item_data);
            } else {
                WC()->cart->add_to_cart( $product_id, $quantity, 0, [], $ob_cart_item_data);
            }
            $data = [
                'status' 		=> 'success',
                'message' 		=> __('Successfully added', 'wpfnl'),
                'order_bump'	=> true
            ];

            do_action( 'wpfunnels/order_bump_accepted', $step_id, $product_id );

            return $data;
        }
        return [];
    }


    /**
     * When order bump reject for woocommerce
     * 
     * @param
     * @return Array
     */
    private function wpfnl_order_bump_reject( $step_id, $product_id, $quantity, $key, $user_id, $funnel_id, $replaceable_ob, $ob_cart_item_data, $should_replace_first_product ){
    
        if( Wpfnl_functions::is_wc_active() ){
            
            // fetch main products
            $checkout_meta 		= new Wpfnl_Default_Meta();
            $main_products		= $checkout_meta->get_main_products( $funnel_id, $step_id );

            WC()->session->set('order_bump_accepted', 'no');
            $i = 0;
            foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                if ($cart_item['product_id'] == $product_id) {
                    //remove single product
                    if( $cart_item['quantity'] == $quantity ){
                        if( $i === 0 ){
                            WC()->cart->remove_cart_item($cart_item_key);
                        }
                        $i++;
                    }
                }
                else if ( $cart_item['variation_id'] == $product_id ) {
                    if( $cart_item['quantity'] == $quantity ){
                        if( $i === 0 ){
                            WC()->cart->remove_cart_item($cart_item_key);
                        }
                        $i++;
                    }
                }
            }
            if ( $should_replace_first_product == 'yes' ) {
                foreach ( $main_products as $main_product ) {
                    WC()->cart->add_to_cart( $main_product['id'], $main_product['quantity'], 0, []);
                }
            }
            $data = [
                'status' => 'success',
                'message' => __('Successfully removed', 'wpfnl'),
            ];
            do_action( 'wpfunnels/order_bump_rejected', $step_id, $product_id );

            return $data;
        }
        return [];
    }


    /**
	 * Get replaceable orderbump products
	 */
	private function get_replaceable_ob_products( $ob_settings ){


		$replaceable_ob = [];
		foreach( $ob_settings as $key=>$settings ){
			if( $settings['isReplace'] ===  'yes' ){
				$replaceable_ob[] = [
					'id'       => $settings['product'],
					'quantity' => $settings['quantity'],
				];
			}
		}

		return $replaceable_ob;

	}


    /**
	 * get calculable price
	 *
	 * @param \WC_Product $product
	 * @param $discount_apply
	 * @return string
	 *
	 * @since 2.0.5
	 */
	private function get_product_price( \WC_Product $product, $discount_apply = 'regular' ) {
		$price = $product->get_regular_price();
		return $discount_apply === 'sale' && $product->get_sale_price() ? $product->get_sale_price() : $price;
	}


    /**
	 * Calculate Discount.
	 * @since 1.1.5
	 */
	private function calculate_custom_price($discount_type, $discount_value, $product_price)
	{
		$custom_price = $product_price;

		if (!empty($discount_type)) {
			if ('discount-percentage' === $discount_type) {
				if ( $discount_value > 0 && $discount_value <= 100) {
					$custom_price = $product_price - (($product_price * $discount_value) / 100);
				}else{
					$custom_price = $product_price;
				}
			} elseif ('discount-price' === $discount_type) {
				if ($discount_value > 0 && $product_price >= $discount_value ) {
					$custom_price = $product_price - $discount_value;
				}else{
					$custom_price = $product_price;
				}
			}
		}

		return number_format($custom_price, 2);
	}



    /**
	 * Update quantity from checkout page
	 *
	 * @param $quantity, $cart_item, $cart_item_key
	 */
	public function wpfnl_checkout_cart_item_quantity( $quantity, $cart_item, $cart_item_key ) {

		$step_id = 0;
		$isQuantity = 'no';

		if( wp_doing_ajax() ) {
			$step_id        = isset($_POST['step_id']) ? $_POST['step_id'] : 0;
		} else {
			$step_id = get_the_ID();
		}


		$isQuantity = get_post_meta($step_id, '_wpfnl_quantity_support',true);
		$order_bump_product = get_post_meta($step_id,'order-bump-settings',true);

		if($isQuantity === 'yes'){
			if(isset($order_bump_product['product']) && isset($order_bump_product['isEnabled'])){

				if( ($order_bump_product['product'] == $cart_item["product_id"]) && $order_bump_product['isEnabled'] == 'yes' ){
					return $quantity;
				}
				$variations = json_encode($cart_item['variation']);
				$product_id = $cart_item["product_id"];
				$quantity = $cart_item["quantity"];
				$variation_id = $cart_item["variation_id"];
				$quantity = "× <input type='number' min='1' value='".$quantity."' class='wpfnl-quantity-setect' data-product-id='".$product_id."' data-variation='".$variations."' data-variation-id='".$variation_id."'/>";
			}
		}
		return $quantity;

	}

}